@@ -15,22 +15,6 @@ void Alignment::initAlignment() {
 }
 void Alignment::setAlignment(BamAlignment * align) {
 	al = align;
-	/*
-	 //comment from here:
-	 //todo: why does this influence the INV detection???
-	 alignment.first.clear();
-	 alignment.second.clear();
-	 is_computed = false;
-
-	 orig_length = al->QueryBases.size();
-
-	 for (size_t i = 0; i < al->QueryBases.size(); i++) {
-	 alignment.first += toupper(al->QueryBases[i]);
-	 alignment.second += 'X';
-	 }
-
-
-	 stop = this->getPosition() + this->getRefLength();*/
 }
 
 void update_aln(std::string & alignment, int & i, int pos_to_modify) {
@@ -47,7 +31,7 @@ void update_aln(std::string & alignment, int & i, int pos_to_modify) {
 void add_event(int pos, list<differences_str>::iterator & i, list<differences_str> & events) {
 	//insert sorted into vector:
 	while (i != events.end() && pos > (*i).position) {
-		i++;
+		++i;
 	}
 	differences_str ev;
 	ev.position = pos;
@@ -63,46 +47,49 @@ void add_event(int pos, size_t & i, vector<differences_str> & events) {
 	differences_str ev;
 	ev.position = pos;
 	ev.type = 0; //mismatch
+	ev.readposition = -1;
 	events.insert(events.begin() + i, ev);
 }
-//todo: check if list changes things
 
-vector<differences_str> Alignment::summarizeAlignment() {
-	//clock_t comp_aln = clock();
+vector<differences_str> Alignment::summarizeAlignment(std::vector<indel_str> &dels) {
+//	clock_t comp_aln = clock();
 	vector<differences_str> events;
 	int pos = this->getPosition();
 	differences_str ev;
 	bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
-
+	int read_pos = 0;
+	if (al->CigarData[0].Type == 'S') {
+		read_pos += al->CigarData[0].Length;
+	}
 	for (size_t i = 0; i < al->CigarData.size(); i++) {
-		if (flag) {
-			//	cout<<al->CigarData[i].Type<<al->CigarData[i].Length<<std::endl;
-		}
-		if (al->CigarData[i].Type == 'D') {
+		if (al->CigarData[i].Type == 'M') {
+			pos += al->CigarData[i].Length;
+			read_pos += al->CigarData[i].Length;
+		} else if (al->CigarData[i].Type == 'D') {
 			ev.position = pos;
 			ev.type = al->CigarData[i].Length; //deletion
+			ev.readposition = read_pos;
 			events.push_back(ev);
 			pos += al->CigarData[i].Length;
 		} else if (al->CigarData[i].Type == 'I') {
 			ev.position = pos;
+			ev.readposition = read_pos;
 			ev.type = al->CigarData[i].Length * -1; //insertion
 			events.push_back(ev);
-		} else if (al->CigarData[i].Type == 'M') {
-			pos += al->CigarData[i].Length;
+			read_pos += al->CigarData[i].Length;
 		} else if (al->CigarData[i].Type == 'N') {
 			pos += al->CigarData[i].Length;
+			read_pos += al->CigarData[i].Length;
 		} else if (al->CigarData[i].Type == 'S' && al->CigarData[i].Length > Parameter::Instance()->huge_ins) { /// Used for reads ranging into an inser
 			string sa;
 			al->GetTag("SA", sa);
 			uint32_t sv;
 			if ((al->GetTag("SV", sv) && sa.empty()) && (!(sv & Ns_CLIPPED) && !(sv & FULLY_EXPLAINED))) { // TODO remove last )
-				if (flag) {
-					std::cout << "Chop: " << pos << " Rname: " << this->getName() << std::endl;
-				}
-				if (pos == this->getPosition()) {
-					ev.position = pos; // - Parameter::Instance()->huge_ins;
+				ev.position = pos; // - Parameter::Instance()->huge_ins;
+				if (i == 0) {
+					ev.readposition = 0;
 				} else {
-					ev.position = pos;
+					ev.readposition = read_pos;
 				}
 				ev.type = Parameter::Instance()->huge_ins * -1; //insertion: WE have to fix the length since we cannot estimate it!]
 				events.push_back(ev);
@@ -110,31 +97,32 @@ vector<differences_str> Alignment::summarizeAlignment() {
 		}
 	}
 
-	if (flag) {
-		std::cout << "FIRST:" << std::endl;
-		for (size_t i = 0; i < events.size(); i++) {
-			if (abs(events[i].type) > 200) {
-				cout << events[i].position << " " << events[i].type << endl;
-			}
-		}
-		cout << endl;
-	}
+	/*if (flag) {
+	 std::cout << "FIRST:" << std::endl;
+	 for (size_t i = 0; i < events.size(); i++) {
+	 if (abs(events[i].type) > 200) {
+	 cout << events[i].position << " " << events[i].type << endl;
+	 }
+	 }
+	 cout << endl;
+	 }*/
 
-	//set ref length requ. later on:
+//set ref length requ. later on:
 	this->ref_len = pos - getPosition(); //TODO compare to get_length!
-
-			//cout<<" comp len: "<<this->ref_len<<" "<<pos<<" "<<this->getPosition()<<endl;
-//	Parameter::Instance()->meassure_time(comp_aln, "\t\tCigar: ");
+			//Parameter::Instance()->meassure_time(comp_aln, "\t\tCigar: ");
 
 	string md = this->get_md();
 	pos = this->getPosition();
 	int corr = 0;
 	bool match = false;
-	bool gap;
+	bool gap = false;
 	int ref_pos = 0;
 	size_t pos_events = 0;
 	int max_size = (this->getRefLength() * 0.9) + getPosition();
-	//comp_aln = clock();
+//	comp_aln = clock();
+	indel_str del;
+	del.sequence = "";
+	del.pos = -1;
 	for (size_t i = 0; i < md.size() && pos < max_size; i++) {
 		if (md[i] == '^') {
 			gap = true;
@@ -150,69 +138,29 @@ vector<differences_str> Alignment::summarizeAlignment() {
 				}
 				//store in sorted order:
 				add_event(pos, pos_events, events);
-
-				pos++; //just the pos on ref!
+				pos++;			//just the pos on ref!
+			} else if (Parameter::Instance()->print_seq) { //can only be a deletion:
+				if (del.pos == -1) {
+					del.pos = pos;
+				} else { //avoid first string position;
+					del.sequence += md[i];
+				}
 			}
 			match = false;
 		} else if (!match) {
 			match = true;
 			pos += atoi(&md[i]);
 			gap = false;
-		}
-	}
-
-	if (flag) {
-		std::cout << "SECOND:" << std::endl;
-		for (size_t i = 0; i < events.size(); i++) {
-			if (abs(events[i].type) > 200) {
-				cout << events[i].position << " " << events[i].type << endl;
+			if (Parameter::Instance()->print_seq && del.sequence.size() > Parameter::Instance()->min_length) {
+				dels.push_back(del);
 			}
+			del.sequence = "";
+			del.pos = -1;
 		}
-		cout << endl;
 	}
 
-	//Parameter::Instance()->meassure_time(comp_aln, "\t\tMD string: ");
-//	comp_aln = clock();
-	size_t i = 0;
-	//to erase stretches of consecutive mismatches == N in the ref
-	/*int break_point = 0;
-	 while (i < events.size()) {
-	 if (events[i].position > max_size) {
-	 while (i < events.size()) {
-	 if (abs(events[events.size() - 1].type) == Parameter::Instance()->huge_ins) {
-	 i++;
-	 } else {
-	 events.erase(events.begin() + i, events.begin() + i + 1);
-	 }
-	 }
-	 break;
-	 }
-	 if (events[i].type == 0) {
-	 size_t j = 1;
-	 while (i + j < events.size() && ((events[i + j].position - events[i + (j - 1)].position) == 1 && events[i + j].type == 0)) {
-	 j++;
-	 }
-	 if (j > 10) { //if stetch is at least 3 consecutive mismatches
-	 events.erase(events.begin() + i, events.begin() + i + j);
-	 } else {
-	 i += j;
-	 }
-	 } else {
-	 i++;
-	 }
-	 }*/
-//	Parameter::Instance()->meassure_time(comp_aln, "\t\terrase N: ");
-	if (flag) {
-		cout << "LAST:" << endl;
-		for (size_t i = 0; i < events.size(); i++) {
-			if (abs(events[i].type) > 200) {
-				cout << events[i].position << " " << events[i].type << endl;
-			}
-		}
-		cout << endl;
+//	Parameter::Instance()->meassure_time(comp_aln, "\t\tMD string: ");
 
-		cout << "total: " << events.size() << endl;
-	}
 	return events;
 }
 void Alignment::computeAlignment() {
@@ -258,7 +206,7 @@ void Alignment::computeAlignment() {
 	}
 	Parameter::Instance()->meassure_time(comp_aln, "\t\tCIGAR opterations ");
 	comp_aln = clock();
-	//Apply MD string:
+//Apply MD string:
 	string md = this->get_md();
 	pos = 0;
 	int corr = 0;
@@ -461,6 +409,7 @@ void Alignment::get_coords(aln_str tmp, int & start, int &stop) {
 	if (!tmp.strand) {
 		index = tmp.cigar.size() - 1;
 	}
+//	cout<<"Cigar: "<<this->getName()<<" "<<tmp.cigar.size()<<" "<<index<<endl;
 	if (tmp.cigar[index].Type == 'S' || tmp.cigar[index].Type == 'H') {
 		start = tmp.cigar[index].Length;
 	} else {
@@ -470,7 +419,7 @@ void Alignment::get_coords(aln_str tmp, int & start, int &stop) {
 }
 void Alignment::check_entries(vector<aln_str> &entries) {
 
-	bool flag =(strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
+	bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
 
 	if (flag) {
 		std::cout << "Nested? " << std::endl;
@@ -505,8 +454,8 @@ void Alignment::check_entries(vector<aln_str> &entries) {
 			if (abs(ref_size - read_size) > Parameter::Instance()->min_length) {
 				valid++;
 			}
-			if(flag){
-			cout<<"Read: "<<read_size << " Ref: "<<ref_size<< " "<<this->getName()<<std::endl;
+			if (flag) {
+				cout << "Read: " << read_size << " Ref: " << ref_size << " " << this->getName() << std::endl;
 			}
 
 			if (chr != entries[i].RefID) {
@@ -522,7 +471,7 @@ void Alignment::check_entries(vector<aln_str> &entries) {
 	if (flag) {
 		std::cout << "summary: " << strands << " " << valid << " " << std::endl;
 	}
-	if (strands < 3 || valid < 2 ) { //check!
+	if (strands < 3 || valid < 2) { //check!
 		if (flag) {
 			std::cout << "Return" << std::endl;
 		}
@@ -614,83 +563,6 @@ void Alignment::check_entries(vector<aln_str> &entries) {
 		std::cout << std::endl;
 	}
 }
-/*void Alignment::check_entries(vector<aln_str> &entries) { //something is not working!
- bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
-
- //Given that we start outside of the INV:
- if (flag) {
- cout << "Check:" << endl;
- for (size_t i = 0; i < entries.size(); i++) {
- cout << "ENT: " << entries[i].pos << " " << entries[i].pos + entries[i].length << " Read: " << entries[i].read_pos_start << " " << entries[i].read_pos_stop << " ";
- if (entries[i].strand) {
- cout << "+" << endl;
- } else {
- cout << "-" << endl;
- }
- }
- check_entries2(entries);
- }
- bool left_of = true;
- vector<aln_str> new_entries = entries;
- for (size_t i = 1; i < entries.size(); i++) {
- if (entries[i].strand != entries[i - 1].strand && entries[i].RefID == entries[i - 1].RefID) {
- int ref_dist = 0;
- int read_dist = 0;
- //all comp with abs:
- //maybe try without abs!:
- if (entries[0].strand) {
- ref_dist = abs((entries[i - 1].pos + entries[i - 1].length) - entries[i].pos);
- read_dist = abs(entries[i - 1].read_pos_stop - entries[i].read_pos_start);
- } else {
- ref_dist = abs((entries[i - 1].pos) - (entries[i].pos + entries[i].length));
- read_dist = abs(entries[i - 1].read_pos_stop - entries[i].read_pos_start);
- }
- if (flag) {
- cout << "ref dist: " << ref_dist << " Read: " << read_dist << " DIFF: " << abs(ref_dist - read_dist) << endl;
- }
-
- if (abs(ref_dist - read_dist) > Parameter::Instance()->min_length) {
- //ref_dist > 30 &&
- if (read_dist < Parameter::Instance()->min_length && ref_dist / (read_dist + 1) > 3) { //+1 because otherwise there could be a division by 0!
- if (flag) {
- cout << "DEL? " << ref_dist << " " << read_dist << endl;
- }
- aln_str tmp;
- tmp.RefID = entries[i].RefID;
- if (left_of) {
- tmp.strand = entries[i - 1].strand;
- if (tmp.strand) {
- tmp.pos = entries[i].pos - 1;
- } else {
- tmp.pos = entries[i].pos + entries[i].length - 1;
- }
- left_of = false;
- } else {
- tmp.strand = entries[i].strand;
- if (tmp.strand) {
- tmp.pos = entries[i - 1].pos + entries[i - 1].length - 1;
- } else {
- tmp.pos = entries[i - 1].pos - 1;
- }
- left_of = true;
- }
- tmp.length = 1;
- tmp.read_pos_start = entries[i].read_pos_start - 1;
- tmp.read_pos_stop = tmp.read_pos_start + 1;
- tmp.mq = 60;
- sort_insert(tmp, new_entries);
- } else if (read_dist > Parameter::Instance()->min_length && ref_dist < 10) {
- //cout << "INS? " << this->getName() << endl;
- }
- }
- } else {
- left_of = true; //??
- }
- }
- if (entries.size() < new_entries.size()) {
- entries = new_entries;
- }
- }*/
 
 void Alignment::sort_insert_ref(aln_str tmp, vector<aln_str> &entries) {
 
@@ -742,6 +614,9 @@ vector<aln_str> Alignment::getSA(RefVector ref) {
 		bool flag = strcmp(getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0;
 
 		get_coords(tmp, tmp.read_pos_start, tmp.read_pos_stop);
+		if (flag) {
+			cout << "\t read " << tmp.read_pos_start << " stop " << tmp.read_pos_stop << endl;
+		}
 		entries.push_back(tmp);
 		if (flag) {
 			std::cout << "Main Read: read start:" << tmp.read_pos_start << " REF: " << tmp.pos << " RefID: " << tmp.RefID << std::endl;
@@ -775,12 +650,15 @@ vector<aln_str> Alignment::getSA(RefVector ref) {
 			if (sa[i] == ',') {
 				count++;
 			}
-			if (sa[i] == ';') {
+			if (sa[i] == ';' && !cigar.empty()) {
 				//TODO: maybe check how often this happens per read!
 				if ((tmp.mq > Parameter::Instance()->min_mq || sv & FULLY_EXPLAINED) && entries.size() <= Parameter::Instance()->max_splits) {
 					//TODO: check this!
 					tmp.cigar = translate_cigar(cigar); //translates the cigar (string) to a type vector
 					get_coords(tmp, tmp.read_pos_start, tmp.read_pos_stop); //get the coords on the read.
+					if (flag) {
+						cout << "\t read " << tmp.read_pos_start << " stop " << tmp.read_pos_stop << endl;
+					}
 					tmp.length = (long) get_length(tmp.cigar); //gives the length on the reference.
 					tmp.RefID = get_id(ref, chr); //translates back the chr to the id of the chr;
 					//TODO: should we do something about the MD string?
@@ -848,11 +726,10 @@ bool Alignment::get_is_save() {
 
 	double score = get_scrore_ratio(); //TODO should I use this again for bwa?
 
-	return !((al->GetTag("XA", sa) && !sa.empty()) || (al->GetTag("XT", sa) && !sa.empty())) && (score == -1 || score > Parameter::Instance()->score_treshold);					//|| //TODO: 7.5
+	return !((al->GetTag("XA", sa) && !sa.empty()) || (al->GetTag("XT", sa) && !sa.empty())) && (score == -1 || score > Parameter::Instance()->score_treshold); //|| //TODO: 7.5
 }
 
 std::vector<CigarOp> Alignment::translate_cigar(std::string cigar) {
-
 	std::vector<CigarOp> new_cigar;
 
 	size_t i = 0;
@@ -1086,7 +963,8 @@ vector<int> Alignment::get_avg_diff(double & dist, double & avg_del, double & av
 //cout<<alignment.first<<endl;
 //cout<<alignment.second<<endl;
 	vector<int> mis_per_window;
-	vector<differences_str> event_aln = summarizeAlignment();
+	std::vector<indel_str> dels;
+	vector<differences_str> event_aln = summarizeAlignment(dels);
 	if (event_aln.empty()) {
 		dist = 0;
 		return mis_per_window;
@@ -1131,13 +1009,11 @@ vector<int> Alignment::get_avg_diff(double & dist, double & avg_del, double & av
 
 vector<str_event> Alignment::get_events_Aln() {
 
-	bool flag = (strcmp(this->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
+	bool flag = (strcmp(this->getName().c_str(),Parameter::Instance()->read_name.c_str()) == 0);
 
 //clock_t comp_aln = clock();
-	vector<differences_str> event_aln = summarizeAlignment();
-	if (flag) {
-		std::cout << "test size: " << event_aln.size() << std::endl;
-	}
+	std::vector<indel_str> dels;
+	vector<differences_str> event_aln = summarizeAlignment(dels);
 //double time2 = Parameter::Instance()->meassure_time(comp_aln, "\tcompAln Events: ");
 
 	vector<str_event> events;
@@ -1165,9 +1041,6 @@ vector<str_event> Alignment::get_events_Aln() {
 			profile.push_back(tmp);
 		} else if (abs(event_aln[i].type) > Parameter::Instance()->min_length) {	//for single events like NGM-LR would produce them.
 			tmp.position = event_aln[i].position;
-			if (flag) {
-				std::cout << "HIT" << std::endl;
-			}
 			profile.push_back(tmp);
 		}
 	}
@@ -1176,9 +1049,7 @@ vector<str_event> Alignment::get_events_Aln() {
 	int stop = 0;
 	size_t start = 0;
 	for (size_t i = 0; i < profile.size() && stop < event_aln.size(); i++) {
-		if (flag) {
-			std::cout << "Prof: " << profile[i].position << " " << event_aln[stop].position << std::endl;
-		}
+
 		if (profile[i].position >= event_aln[stop].position) {
 			//find the postion:
 			size_t pos = 0;
@@ -1190,9 +1061,6 @@ vector<str_event> Alignment::get_events_Aln() {
 			int prev = event_aln[pos].position;
 			start = pos;
 			int prev_type = 1;
-			if (flag) {
-				std::cout << "check start" << std::endl;
-			}
 			//todo it is actually pos + type and not *type
 			while (start > 0 && (prev - event_aln[start].position) < (Parameter::Instance()->max_dist_alns)) {	//13		//} * abs(event_aln[start].type) + 1)) { //TODO I  dont like 13!??
 				prev = event_aln[start].position;
@@ -1210,9 +1078,6 @@ vector<str_event> Alignment::get_events_Aln() {
 			prev = event_aln[pos].position;
 			stop = pos;
 			prev_type = 1;
-			if (flag) {
-				std::cout << "check stop" << std::endl;
-			}
 			while (stop < event_aln.size() && (event_aln[stop].position - prev) < (Parameter::Instance()->max_dist_alns)) {		// * abs(event_aln[stop].type) + 1)) {
 				prev = event_aln[stop].position;
 
@@ -1239,12 +1104,7 @@ vector<str_event> Alignment::get_events_Aln() {
 			double insert = 0;
 			double del = 0;
 			double mismatch = 0;
-//			if (flag) {
-//				cout << start << " " << stop << endl;
-//			}
-			if (flag) {
-				std::cout << "check total len: " << start << " " << stop << std::endl;
-			}
+
 			for (size_t k = start; k <= stop; k++) {
 				if (event_aln[k].type == 0) {
 					mismatch++;
@@ -1271,60 +1131,78 @@ vector<str_event> Alignment::get_events_Aln() {
 			}
 			tmp.length = (tmp.length - event_aln[start].position);
 
-			if (flag) {
-				std::cout << "decide" << std::endl;
-			}
 			tmp.type = 0;
 			if (insert_max > Parameter::Instance()->min_length && insert > (del + del)) { //we have an insertion! //todo check || vs. &&
-				if (flag) {
-					cout << "store INS" << endl;
-				}
-				tmp.length = insert_max; //TODO not sure!
-				tmp.pos = insert_max_pos;
-				tmp.type |= INS;
-				tmp.is_noise = false;
 				if (is_N_region && insert_max * Parameter::Instance()->avg_ins < Parameter::Instance()->min_length) {
 					tmp.type = 0;
+				} else {
+					tmp.length = insert_max; //TODO not sure!
+					while (start < stop && event_aln[start].readposition == -1) {
+						if (flag) {
+							cout << event_aln[start].readposition << " " << event_aln[start].type << endl;
+						}
+						start++;
+					}
+					if (flag) {
+						cout << event_aln[start].readposition << " " << event_aln[start].type << endl;
+					}
+					tmp.read_pos = event_aln[start].readposition;
+					if (Parameter::Instance()->print_seq) {
+						//if (tmp.read_pos + tmp.length > this->getAlignment()->QueryBases.size() || tmp.read_pos<0) {
+						//	cerr << "BUG! ALN event INS: " << this->getName() << " " << tmp.read_pos << " " << tmp.length << " " << this->getAlignment()->QueryBases.size() << endl;
+						//	}
+						if(flag){
+							std::cout<<"Seq+:"<<this->getAlignment()->QueryBases.substr(tmp.read_pos, tmp.length)<<std::endl;
+
+						}
+						tmp.sequence = this->getAlignment()->QueryBases.substr(tmp.read_pos, tmp.length);
+					} else {
+						tmp.sequence = "NA";
+					}
+					tmp.pos = insert_max_pos;
+					tmp.type |= INS;
+					tmp.is_noise = false;
 				}
 			} else if (del_max > Parameter::Instance()->min_length && (insert + insert) < del) { //deletion
-				if (flag) {
-					cout << "store DEL " << this->getName() << endl;
-				}
-				tmp.length = del_max;
-				tmp.type |= DEL;
-				tmp.is_noise = false;
 				if (is_N_region && del_max * Parameter::Instance()->avg_del < Parameter::Instance()->min_length) {
 					tmp.type = 0;
+				} else {
+					if (Parameter::Instance()->print_seq) {
+						for (size_t del_pos = 0; del_pos < dels.size(); del_pos++) {
+							if (abs(dels[del_pos].pos - tmp.pos) < 10) {
+								tmp.sequence = dels[del_pos].sequence;
+							}
+						}
+					} else {
+						tmp.sequence = "NA";
+					}
+					tmp.length = del_max;
+					tmp.type |= DEL;
+					tmp.is_noise = false;
 				}
 			} else if ((mismatch + del + insert) / 2 > Parameter::Instance()->min_length) { //TODO
-				if (flag) {
-					cout << "store Noise" << endl;
-				}
-				noise_events++;
-				tmp.type |= DEL;
-				tmp.type |= INV;
-				tmp.is_noise = true;
-				if (is_N_region || ((del_max> Parameter::Instance()->min_length && insert_max > Parameter::Instance()->min_length) && (del_max/insert_max)<Parameter::Instance()->min_length)) {
+				if (is_N_region || ((del_max > Parameter::Instance()->min_length && insert_max > Parameter::Instance()->min_length) && (del_max / insert_max) < Parameter::Instance()->min_length)) {
 					tmp.type = 0;
+				} else {
+					noise_events++;
+					tmp.type |= DEL;
+					tmp.type |= INV;
+					tmp.sequence = "NA";
+					tmp.is_noise = true;
 				}
-			} else {
-				//	std::cout<<"ERROR we did not set the type!"<<std::endl;
-				tmp.type = 0;
 			}
 
 			if (flag) {
-				cout << "Read: " << " " << (double) this->getRefLength() << " events: " << event_aln.size() << " " << this->al->Name << std::endl;
-				cout << "INS max " << insert_max << " del_max " << del_max << std::endl;
-				cout << "INS:" << insert << " DEL: " << del << " MIS: " << mismatch << endl;
-				cout << event_aln[start].position << " " << event_aln[stop].position << endl;
-				cout << "store: " << tmp.pos << " " << tmp.pos + abs(tmp.length) << " " << tmp.length << endl;
-				cout << endl;
-			}
+			 cout << "Read: " << " " << (double) this->getRefLength() << " events: " << event_aln.size() << " " << this->al->Name << std::endl;
+			 cout << "INS max " << insert_max << " del_max " << del_max << std::endl;
+			 cout << "INS:" << insert << " DEL: " << del << " MIS: " << mismatch << endl;
+			 cout << event_aln[start].position << " " << event_aln[stop].position << endl;
+			 cout << "store: " << tmp.pos << " " << tmp.pos + abs(tmp.length) << " " << tmp.length << endl;
+			 cout << tmp.sequence<<endl;
+			 cout << endl;
+			 }
 
 			if (tmp.type != 0) {
-				if (flag) {
-					cout << "STORE" << endl;
-				}
 				events.push_back(tmp);
 			}
 		}
