@@ -20,14 +20,16 @@ class Genotyper{
 private:
 	Breakpoint_Tree tree;
 	breakpoint_node * node;
-	void read_SVs(Breakpoint_Tree & tree,breakpoint_node *& node );
-	void compute_cov(Breakpoint_Tree & tree,breakpoint_node *& node);
+	std::vector<std::string>  read_SVs(Breakpoint_Tree & tree,breakpoint_node *& node );
+	void compute_cov(Breakpoint_Tree & tree,breakpoint_node *& node,std::vector<std::string>  ref_dict);
 	void update_file(Breakpoint_Tree & tree,breakpoint_node *& node);
-	variant_str get_breakpoint_vcf(char *buffer);
-	variant_str get_breakpoint_bedpe(char *buffer);
-	std::string mod_breakpoint_vcf(char *buffer, int ref);
-	std::string mod_breakpoint_bedpe(char *buffer, int ref);
+	variant_str get_breakpoint_vcf(string buffer);
+	variant_str get_breakpoint_bedpe(string buffer);
+	std::string mod_breakpoint_vcf(string buffer, int ref);
+	std::string mod_breakpoint_bedpe(string buffer, int ref);
 	void parse_pos(char * buffer, int & pos, std::string & chr);
+
+
 public:
 	Genotyper(){
 		node=NULL;
@@ -36,5 +38,7 @@ public:
 
 	}
 	void update_SVs();
+	void update_SVs(std::vector<Breakpoint *> & points,long ref_space);
+	std::string assess_genotype(int ref, int support);
 };
 #endif /* GENOTYPER_H_ */
