@@ -14,6 +14,7 @@
 #include <stdlib.h>
 #include <iostream>
 #include <ctime>
+#include <map>
 struct region_str {
 	std::string chr;
 	int start;
@@ -24,7 +25,7 @@ class Parameter {
 private:
 	Parameter() {
 		window_thresh=10;//TODO check!
-		version="1.0.6";
+		version="1.0.7";
 		huge_ins = 2000;//TODO check??
 	}
 	~Parameter() {
@@ -39,9 +40,13 @@ public:
 	std::string read_name;
 	std::string ignore_regions_bed;
 	std::string tmp_file;
+	std::string tmp_genotyp;
+	std::string tmp_phasing;
 	std::string version;
+	std::string input_vcf;
 
 	std::vector<std::string> bam_files;
+	std::map<std::string, bool> chr_names;
 	short min_mq;
 	short report_n_reads;
 	short corridor;
@@ -51,6 +56,8 @@ public:
 	double min_allelel_frequency;
 	double avg_del;
 	double avg_ins;
+	double homfreq;
+	double hetfreq;
 	//double min_num_mismatches;
 
 	int window_thresh;
@@ -65,6 +72,7 @@ public:
 	int huge_ins;
 	int max_dist_alns;
 	int min_segment_size;
+	int min_zmw;
 
 //	bool splitthreader_output;
 	bool debug;
@@ -72,6 +80,7 @@ public:
 	bool phase;
 	bool ignore_std;
 	bool reportBND;
+	bool print_seq;
 
 	void set_regions(std::string reg) {
 		size_t i = 0;
