@@ -139,7 +139,7 @@ long Breakpoint::overlap(Breakpoint * tmp) {
 	}
 
 	//merging "huge ins" and observed ins:
-	if(is_same_strand(tmp) && (abs(tmp->get_coordinates().start.min_pos -tmp->get_coordinates().stop.max_pos) == Parameter::Instance()->huge_ins || abs(positions.start.min_pos -positions.stop.max_pos) == Parameter::Instance()->huge_ins) && (abs(tmp->get_coordinates().start.min_pos - positions.start.min_pos) < max_dist || abs(tmp->get_coordinates().stop.max_pos - positions.stop.max_pos) < max_dist)){
+	if (is_same_strand(tmp) && (abs(tmp->get_coordinates().start.min_pos - tmp->get_coordinates().stop.max_pos) == Parameter::Instance()->huge_ins || abs(positions.start.min_pos - positions.stop.max_pos) == Parameter::Instance()->huge_ins) && (abs(tmp->get_coordinates().start.min_pos - positions.start.min_pos) < max_dist || abs(tmp->get_coordinates().stop.max_pos - positions.stop.max_pos) < max_dist)) {
 		return 0;
 	}
 
@@ -168,11 +168,27 @@ long Breakpoint::overlap(Breakpoint * tmp) {
 	return diff; // + (tmp->get_coordinates().stop.max_pos - positions.stop.max_pos);
 }
 
+long Breakpoint::overlap_breakpoint(long start, long stop) {
+	int max_dist = get_dist(this); // Parameter::Instance()->max_dist
+	if ((start < positions.start.min_pos && positions.start.min_pos < stop) || (start < positions.stop.max_pos && positions.stop.max_pos < stop)) {
+		return 0;
+	}
+	long diff = (start - positions.start.min_pos);
+	//if (abs(diff) < max_dist) {
+	//return (tmp->get_coordinates().stop.max_pos - positions.stop.max_pos);
+	//}
+	if (diff == 0) {
+		return 1;
+	}
+	return diff;
+
+}
 void Breakpoint::add_read(Breakpoint * point) { //point = one read support!
 
 	if (point != NULL) {
 		//merge the support:
 		std::map<std::string, read_str> support = point->get_coordinates().support;
+		this->set_refcount(max(point->get_refcount(), this->get_refcount())); //set ref count!
 		for (std::map<std::string, read_str>::iterator i = support.begin(); i != support.end(); i++) {
 			this->positions.support[(*i).first] = (*i).second;
 		}
@@ -180,15 +196,18 @@ void Breakpoint::add_read(Breakpoint * point) { //point = one read support!
 }
 
 ///////////////////////////////// MERGING////////////////////////////////////////////
-std::vector<std::string> Breakpoint::get_read_names(int maxim) {
-	std: vector<std::string> read_names;
-	std::map<std::string, read_str> support = this->positions.support;
-	int num = 0;
-	for (std::map<std::string, read_str>::iterator i = support.begin(); (num < maxim || maxim == -1) && i != support.end(); i++) {
-		read_names.push_back((*i).first);
-		num++;
+std::string Breakpoint::get_read_names() {
+	std::string read_names;
+	int num = Parameter::Instance()->report_n_reads;
+	if (num == -1) {
+		num = this->positions.support.size();
 	}
-	return read_names;
+	for (std::map<std::string, read_str>::iterator i = this->positions.support.begin(); num != 0 && i != this->positions.support.end(); i++) {
+		read_names += ",";
+		read_names += (*i).first;
+		num--;
+	}
+	return read_names.substr(1);
 }
 
 std::vector<long> Breakpoint::get_read_ids() {
@@ -217,7 +236,7 @@ std::string Breakpoint::translate_strand(pair<bool, bool> strand_pair) {
 	return " ";
 }
 
-void Breakpoint::summarize_type(char SV, std::vector<short>& array) {
+void Breakpoint::summarize_type(char SV, ushort * array) {
 //std::string ss;
 	if (SV & DEL) {
 		//	ss += "DEL; ";
@@ -261,58 +280,39 @@ char Breakpoint::get_SVtype() {
 }
 
 void Breakpoint::calc_support() {
-	std::vector<short> SV;
-	for (size_t i = 0; i < 6; i++) {
-		SV.push_back(0);
-	}
+
+	ushort sv[6] = { 0, 0, 0, 0, 0, 0 };
+
 //run over all supports and check the majority type:
 	for (std::map<std::string, read_str>::iterator i = positions.support.begin(); i != positions.support.end(); i++) {
-		summarize_type((*i).second.SV, SV);
+		summarize_type((*i).second.SV, sv);
 	}
 //given the majority type get the stats:
-	this->sv_type = eval_type(SV);
+	this->sv_type = eval_type(sv);
+
+	if (get_SVtype() & TRA) { // we cannot make assumptions abut support yet.
+		set_valid((bool) (get_support() > 1)); // this is needed as we take each chr independently and just look at the primary alignment
+	} else if (get_support() >= Parameter::Instance()->min_support) {
+		predict_SV();
+		set_valid((bool) (get_length() > Parameter::Instance()->min_length));
+	}
 
 }
 
-char Breakpoint::eval_type(std::vector<short> SV) {
-	/*std::stringstream ss;
-	 if (SV[0] != 0) {
-	 ss << " DEL(";
-	 ss << SV[0];
-	 ss << ")";
-	 }
-	 if (SV[1] != 0) {
-	 ss << " DUP(";
-	 ss << SV[1];
-	 ss << ")";
-	 }
-	 if (SV[2] != 0) {
-	 ss << " INS(";
-	 ss << SV[2];
-	 ss << ")";
-	 }
-	 if (SV[3] != 0) {
-	 ss << " INV(";
-	 ss << SV[3];
-	 ss << ")";
-	 }
-	 if (SV[4] != 0) {
-	 ss << " TRA(";
-	 ss << SV[4];
-	 ss << ")";
-	 }
-	 this->sv_debug = ss.str(); //only for debug!
-	 std::cout << sv_debug << std::endl;*/
-
+char Breakpoint::eval_type(ushort* SV) {
 	int maxim = 0;
 	int id = 0;
-	for (size_t i = 0; i < SV.size(); i++) {
+	for (size_t i = 0; i < 6; i++) {
 		if (maxim < SV[i]) {
 			maxim = SV[i];
 		}
 	}
 	this->type_support = maxim;
+	if (!Parameter::Instance()->input_vcf.empty()) {
+		this->type_support--; // this is needed since we introduce a pseudo element
+	}
 	char max_SV = 0;
+
 	if (maxim == SV[0]) {
 		max_SV |= DEL;
 	}
@@ -340,8 +340,8 @@ long get_median(std::vector<long> corrds) {
 		return (corrds[corrds.size() / 2 - 1] + corrds[corrds.size() / 2]) / 2;
 	}
 	return corrds[corrds.size() / 2];
-
 }
+
 void Breakpoint::predict_SV() {
 	bool aln = false;
 	bool split = false;
@@ -356,7 +356,8 @@ void Breakpoint::predict_SV() {
 	std::vector<long> lengths2;
 
 	for (std::map<std::string, read_str>::iterator i = positions.support.begin(); i != positions.support.end(); i++) {
-		if ((*i).second.SV & this->sv_type) {			// && !((*i).second.SV & INS && (*i).second.length==Parameter::Instance()->huge_ins)) { ///check type
+
+		if (((*i).second.SV & this->sv_type) && strncmp((*i).first.c_str(), "input", 5) != 0) {			// && !((*i).second.SV & INS && (*i).second.length==Parameter::Instance()->huge_ins)) { ///check type
 
 			if ((*i).second.coordinates.first != -1) {
 				if ((*i).second.length != Parameter::Instance()->huge_ins) {
@@ -368,6 +369,7 @@ void Breakpoint::predict_SV() {
 				}
 				start2.push_back((*i).second.coordinates.first);
 			}
+
 			if ((*i).second.coordinates.second != -1) { //TODO test
 				if ((*i).second.length != Parameter::Instance()->huge_ins) {
 					if (stops.find((*i).second.coordinates.second) == stops.end()) {
@@ -378,7 +380,8 @@ void Breakpoint::predict_SV() {
 				}
 				stops2.push_back((*i).second.coordinates.second);
 			}
-			if (((*i).second.SV & INS) ) { //check lenght for ins only!
+
+			if (((*i).second.SV & INS)) { //check lenght for ins only!
 				if ((*i).second.length != Parameter::Instance()->huge_ins) {
 					if (lengths.find((*i).second.length) == lengths.end()) {
 						lengths[(*i).second.length] = 1;
@@ -415,88 +418,101 @@ void Breakpoint::predict_SV() {
 	long counts = 0;
 	int maxim = 0;
 	long coord = 0;
+	if (num > 0) {
 
-	for (map<long, int>::iterator i = starts.begin(); i != starts.end(); i++) {
-		//	cout << "start:\t" << (*i).first << " " << (*i).second << endl;
-		if ((*i).second > maxim) {
-			coord = (*i).first;
-			maxim = (*i).second;
-		}
-		//mean += ((*i).first * (*i).second);
-		//	counts += (*i).second;
-	}
-	if (maxim < 5) {
-		this->positions.start.most_support = get_median(start2);	//mean / counts;
-	} else {
-		this->positions.start.most_support = coord;
-	}
-
-	maxim = 0;
-	coord = 0;
-	mean = 0;
-	counts = 0;
-	for (map<long, int>::iterator i = stops.begin(); i != stops.end(); i++) {
-		//	cout << "stop:\t" << (*i).first << " " << (*i).second << endl;
-		if ((*i).second > maxim) {
-			coord = (*i).first;
-			maxim = (*i).second;
-		}
-		//mean += ((*i).first * (*i).second);
-		//	counts += (*i).second;
-	}
-	if (maxim < 5) {
-		this->positions.stop.most_support = get_median(stops2);	// mean / counts;
-	} else {
-		this->positions.stop.most_support = coord;
-	}
-	/*if(this->get_SVtype() & NEST){
-	 this->length = -1;
-	 }else
-	 */
-
-	if (!(this->get_SVtype() & INS)) { //all types but Insertions:
-		this->length = this->positions.stop.most_support - this->positions.start.most_support;
-	} else { //compute most supported length for insertions:
-		maxim = 0;
-		coord = 0;
-		mean = 0;
-		counts = 0;
-		for (map<long, int>::iterator i = lengths.begin(); i != lengths.end(); i++) {
-			//	std::cout<<"LENGTH: "<<(*i).first<<" : "<<(*i).second<<std::endl;
+		for (map<long, int>::iterator i = starts.begin(); i != starts.end(); i++) {
 			if ((*i).second > maxim) {
 				coord = (*i).first;
 				maxim = (*i).second;
 			}
-			//	mean += ((*i).first * (long) (*i).second);
-			//	counts += (*i).second;
 		}
-		if (maxim < 3) {
-			this->length = get_median(lengths2);
+		if (maxim < 5) {
+			this->positions.start.most_support = get_median(start2);	//check if "input"!
 		} else {
-			this->length = coord;
+			this->positions.start.most_support = coord;
 		}
+		this->indel_sequence = "";
 
-	}
 
-	starts.clear();
-	stops.clear();
-
-	for (size_t i = 0; i < strands.size(); i++) {
 		maxim = 0;
-		std::string id;
-		for (std::map<std::string, int>::iterator j = strands.begin(); j != strands.end(); j++) {
-			if (maxim < (*j).second) {
-				maxim = (*j).second;
-				id = (*j).first;
-				//std::cout << '\t' << id << std::endl;
+		coord = 0;
+		mean = 0;
+		counts = 0;
+		for (map<long, int>::iterator i = stops.begin(); i != stops.end(); i++) {
+			if ((*i).second > maxim) {
+				coord = (*i).first;
+				maxim = (*i).second;
 			}
 		}
-		if (maxim > 0) {
-			this->strand.push_back(id);
-			strands[id] = 0;
+		if (maxim < 5) {
+			this->positions.stop.most_support = get_median(stops2);	// mean / counts;
+		} else {
+			this->positions.stop.most_support = coord;
+		}
+
+		if (!(this->get_SVtype() & INS)) { //all types but Insertions:
+			this->length = this->positions.stop.most_support - this->positions.start.most_support;
+
+		} else { //compute most supported length for insertions:
+			maxim = 0;
+			coord = 0;
+			mean = 0;
+			counts = 0;
+			for (map<long, int>::iterator i = lengths.begin(); i != lengths.end(); i++) {
+				if ((*i).second > maxim) {
+					coord = (*i).first;
+					maxim = (*i).second;
+				}
+
+			}
+			if (maxim < 3) {
+				this->length = get_median(lengths2);
+			} else {
+				this->length = coord;
+			}
+
+			//	if(del)
+		}
+
+		starts.clear();
+		stops.clear();
+
+		for (size_t i = 0; i < strands.size(); i++) {
+			maxim = 0;
+			std::string id;
+			for (std::map<std::string, int>::iterator j = strands.begin(); j != strands.end(); j++) {
+				if (maxim < (*j).second) {
+					maxim = (*j).second;
+					id = (*j).first;
+					//std::cout << '\t' << id << std::endl;
+				}
+			}
+			if (maxim > 0) {
+				this->strand.push_back(id);
+				strands[id] = 0;
+			}
+		}
+		strands.clear();
+
+
+		std::map<std::string, read_str>::iterator tmp = positions.support.begin();
+		int start_prev_dist=1000;
+		int stop_prev_dist=1000;
+		while(tmp != positions.support.end()) {
+			int start_dist=abs((*tmp).second.coordinates.first- this->positions.start.most_support);
+			int stop_dist=abs((*tmp).second.coordinates.second- this->positions.stop.most_support);
+			if (((*tmp).second.SV & this->sv_type) && ( (start_dist<start_prev_dist && stop_dist<stop_prev_dist)  && (strcmp((*tmp).second.sequence.c_str(), "NA") != 0 && !(*tmp).second.sequence.empty()))) {
+				this->indel_sequence = (*tmp).second.sequence;
+			}
+			tmp++;
 		}
 	}
-	strands.clear();
+
+	if (num == 0 && positions.support.find("input") != positions.support.end()) {
+		this->positions.stop.most_support = this->positions.stop.max_pos;
+		this->positions.start.most_support = this->positions.start.min_pos;
+		this->length = this->positions.stop.max_pos - this->positions.start.min_pos;
+	}
 
 	this->supporting_types = "";
 	if (aln) {
@@ -606,15 +622,14 @@ std::string Breakpoint::to_string() {
 		ss << get_coordinates().stop.max_pos;
 		ss << " ";
 		ss << this->length;
-		ss << " ";
+		ss << " PE=";
 		ss << positions.support.size();
 		ss << " ";
-		ss << get_strand(2);
+		ss << get_strand(1);
 	}
 	return ss.str();
 }
 std::string Breakpoint::to_string(RefVector ref) {
-
 	std::stringstream ss;
 	ss << "(";
 	ss << get_chr(get_coordinates().start.min_pos, ref);
@@ -632,7 +647,10 @@ std::string Breakpoint::to_string(RefVector ref) {
 	ss << this->get_strand(2);
 	ss << "\n";
 	int num = 0;
-	for (std::map<std::string, read_str>::iterator i = positions.support.begin(); i != positions.support.end() && num < Parameter::Instance()->report_n_reads; i++) {
+	for (std::map<std::string, read_str>::iterator i = positions.support.begin(); i != positions.support.end(); i++) {
+		if (num < Parameter::Instance()->report_n_reads && Parameter::Instance()->report_n_reads != -1) {
+			break;
+		}
 		ss << "\t";
 		ss << (*i).first;
 		ss << " ";
@@ -648,6 +666,7 @@ std::string Breakpoint::to_string(RefVector ref) {
 			ss << "-";
 		}
 		num++;
+
 		ss << "\n";
 	}
 	ss << " ";
