@@ -8,18 +8,6 @@
 #include "Detect_Breakpoints.h"
 #include "../print/IPrinter.h"
 
-long fuck_off(long pos, RefVector ref, std::string &chr) {
-	size_t i = 0;
-	pos -= (ref[i].RefLength + Parameter::Instance()->max_dist);
-
-	while (i < ref.size() && pos >= 0) {
-		i++;
-		pos -= ((long) ref[i].RefLength + (long) Parameter::Instance()->max_dist);
-	}
-	chr = ref[i].RefName;
-	return pos + ref[i].RefLength + (long) Parameter::Instance()->max_dist;
-}
-
 void store_pos(vector<hist_str> &positions, long pos, std::string read_name) {
 	for (size_t i = 0; i < positions.size(); i++) {
 		if (abs(positions[i].position - pos) < Parameter::Instance()->min_length) {
@@ -35,6 +23,30 @@ void store_pos(vector<hist_str> &positions, long pos, std::string read_name) {
 	positions.push_back(tmp);
 }
 
+std::string reverse_complement(std::string sequence) {
+	std::string tmp_seq;
+	for (std::string::reverse_iterator i = sequence.rbegin(); i != sequence.rend(); i++) {
+		switch ((*i)) {
+		case 'A':
+			tmp_seq += 'T';
+			break;
+		case 'C':
+			tmp_seq += 'G';
+			break;
+		case 'G':
+			tmp_seq += 'C';
+			break;
+		case 'T':
+			tmp_seq += 'A';
+			break;
+		default:
+			tmp_seq += (*i);
+			break;
+		}
+	}
+	return tmp_seq;
+}
+
 Breakpoint * split_points(vector<std::string> names, std::map<std::string, read_str> support) {
 	std::map<std::string, read_str> new_support;
 	for (size_t i = 0; i < names.size(); i++) {
@@ -52,40 +64,26 @@ void detect_merged_svs(position_str point, RefVector ref, vector<Breakpoint *> &
 	new_points.clear(); //just in case!
 	vector<hist_str> pos_start;
 	vector<hist_str> pos_stop;
-	for (std::map<std::string, read_str>::iterator i = point.support.begin(); i != point.support.end(); i++) {
-		//	std::cout << (*i).second.coordinates.first << "," << (*i).second.coordinates.second << std::endl;
+	for (std::map<std::string, read_str>::iterator i = point.support.begin(); i != point.support.end(); ++i) {
 		store_pos(pos_start, (*i).second.coordinates.first, (*i).first);
 		store_pos(pos_stop, (*i).second.coordinates.second, (*i).first);
 	}
-//	std::cout << "Start: " << std::endl;
+
 	int start_count = 0;
-	//std::cout<<"Start pos: ";
 	for (size_t i = 0; i < pos_start.size(); i++) {
 		//std::cout<<pos_start[i].hits <<",";
 		if (pos_start[i].hits > Parameter::Instance()->min_support) {
 			start_count++;
-			/*		std::string chr = "";
-			 long pos = fuck_off(pos_start[i].position, ref, chr);
-			 std::cout << chr << " " << pos << ":" << pos_start[i].hits << " ; ";
-			 */
+
 		}
 	}
-//	std::cout << std::endl;
-//	std::cout << "Stop: " << std::endl;
 	int stop_count = 0;
 	for (size_t i = 0; i < pos_stop.size(); i++) {
 		//	std::cout << pos_stop[i].hits << ",";
 		if (pos_stop[i].hits > Parameter::Instance()->min_support) {
 			stop_count++;
-			/*	std::string chr = "";
-			 long pos = fuck_off(pos_stop[i].position, ref, chr);
-			 std::cout << chr << " " << pos << ":" << pos_stop[i].hits << " ; ";
-			 */
 		}
 	}
-	//std::cout << std::endl;
-	//std::cout << std::endl;
-
 	if (stop_count > 1 || start_count > 1) {
 		std::cout << "\tprocessing merged TRA" << std::endl;
 		if (start_count > 1) {
@@ -149,19 +147,12 @@ bool should_be_stored(Breakpoint *& point) {
 	point->calc_support(); // we need that before:
 	//std::cout << "Stored: " << point->get_support() << " " << point->get_length() << std::endl;
 	if (point->get_SVtype() & TRA) { // we cannot make assumptions abut support yet.
-		return (point->get_support() > 1); // this is needed as we take each chr independently and just look at the primary alignment
+		point->set_valid((bool) (point->get_support() > 1)); // this is needed as we take each chr independently and just look at the primary alignment
 	} else if (point->get_support() >= Parameter::Instance()->min_support) {
 		point->predict_SV();
-		/*	std::cout<<"LEN check: "<<point->get_length()
-		 if(point->get_length() > Parameter::Instance()->min_length){
-		 cout<<" T "<<std::endl;
-		 }else{
-		 cout<<" T "<<std::endl;
-		 }*/
-		return (point->get_length() > Parameter::Instance()->min_length);
+		point->set_valid((bool) (point->get_length() > Parameter::Instance()->min_length));
 	}
-
-	return false;
+	return point->get_valid();
 }
 void polish_points(std::vector<Breakpoint *> & points, RefVector ref) { //TODO might be usefull! but why does the tree not fully work??
 	return;
@@ -196,9 +187,6 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	std::cout << "Start parsing..." << std::endl;
 //Using Interval tree to store and manage breakpoints:
 
-	//IntervallList final;
-	//IntervallList bst;
-
 	IntervallTree final;
 	IntervallTree bst;
 
@@ -209,30 +197,41 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 //FILE * alt_allel_reads;
 	FILE * ref_allel_reads;
 	if (Parameter::Instance()->genotype) {
-		std::string output = Parameter::Instance()->tmp_file.c_str();
-		output += "ref_allele";
-		ref_allel_reads = fopen(output.c_str(), "wb");
+		ref_allel_reads = fopen(Parameter::Instance()->tmp_genotyp.c_str(), "wb");
 	}
 	Alignment * tmp_aln = mapped_file->parseRead(Parameter::Instance()->min_mq);
 	long ref_space = get_ref_lengths(tmp_aln->getRefID(), ref);
-	//std::string prev = "test";
-	//std::string curr = "curr";
 	long num_reads = 0;
+
+	/*Genotyper * go;
+	if (Parameter::Instance()->genotype) {
+		go = new Genotyper();
+	}*/
+
 	while (!tmp_aln->getQueryBases().empty()) {
-		if ((tmp_aln->getAlignment()->IsPrimaryAlignment()) && (!(tmp_aln->getAlignment()->AlignmentFlag & 0x800) && tmp_aln->get_is_save())) {
+
+		if ((tmp_aln->getAlignment()->IsPrimaryAlignment()) && (!(tmp_aln->getAlignment()->AlignmentFlag & 0x800) && tmp_aln->get_is_save())){// && (Parameter::Instance()->chr_names.empty() || Parameter::Instance()->chr_names.find(ref[tmp_aln->getRefID()].RefName) != Parameter::Instance()->chr_names.end())) {
+
 			//change CHR:
 			if (current_RefID != tmp_aln->getRefID()) {
-				current_RefID = tmp_aln->getRefID();
-				ref_space = get_ref_lengths(tmp_aln->getRefID(), ref);
-				std::cout << "\tSwitch Chr " << ref[tmp_aln->getRefID()].RefName << std::endl;//" " << ref[tmp_aln->getRefID()].RefLength
-				std::vector<Breakpoint *> points;
-				//	clarify(points);
-				bst.get_breakpoints(root, points);
-				polish_points(points, ref);
-				for (int i = 0; i < points.size(); i++) {
 
-					if (should_be_stored(points[i])) {
-						//detect_merged_svs(points[i]);
+				std::cout << "\tSwitch Chr " << ref[tmp_aln->getRefID()].RefName << std::endl;	//" " << ref[tmp_aln->getRefID()].RefLength
+				std::vector<Breakpoint *> points;
+				bst.get_breakpoints(root, points);
+				//polish_points(points, ref);
+
+			/*	if (Parameter::Instance()->genotype) {
+					fclose(ref_allel_reads);
+					cout<<"\t\tGenotyping"<<endl;
+					go->update_SVs(points, ref_space);
+					cout<<"\t\tGenotyping finished"<<endl;
+					ref_allel_reads = fopen(Parameter::Instance()->tmp_genotyp.c_str(), "wb");
+				}*/
+
+				for (int i = 0; i < points.size(); i++) {
+					points[i]->calc_support();
+					if (points[i]->get_valid()) {
+						//invoke update over ref support!
 						if (points[i]->get_SVtype() & TRA) {
 							final.insert(points[i], root_final);
 						} else {
@@ -241,7 +240,10 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 					}
 				}
 				bst.clear(root);
+				current_RefID = tmp_aln->getRefID();
+				ref_space = get_ref_lengths(tmp_aln->getRefID(), ref);
 			}
+
 			//SCAN read:
 			std::vector<str_event> aln_event;
 			std::vector<aln_str> split_events;
@@ -251,42 +253,42 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 				{
 #pragma omp sections
 					{
+#pragma omp section
 						{
-							//	clock_t begin = clock();
+							//		clock_t begin = clock();
 							if ((score == -1 || score > Parameter::Instance()->score_treshold)) {
 								aln_event = tmp_aln->get_events_Aln();
 							}
-							//	Parameter::Instance()->meassure_time(begin, " Alignment ");
+							//		Parameter::Instance()->meassure_time(begin, " Alignment ");
 						}
 #pragma omp section
 						{
-							//TODO ignore Splits that are shorter then XYbp??
-							//		clock_t begin_split = clock();
+							//	clock_t begin_split = clock();
 							split_events = tmp_aln->getSA(ref);
-							//		Parameter::Instance()->meassure_time(begin_split," Split reads ");
+							//	Parameter::Instance()->meassure_time(begin_split, " Split reads ");
 						}
 					}
 				}
 				//tmp_aln->set_supports_SV(aln_event.empty() && split_events.empty());
 
 				//Store reference supporting reads for genotype estimation:
-				str_read tmp;
-				tmp.SV_support = !(aln_event.empty() && split_events.empty());
-				if ((Parameter::Instance()->genotype && !tmp.SV_support) && (score == -1 || score > Parameter::Instance()->score_treshold)) {
+
+				bool SV_support = (!aln_event.empty() && !split_events.empty());
+				if (Parameter::Instance()->genotype && !SV_support) {
 					//write read:
-					tmp.chr = ref[tmp_aln->getRefID()].RefName;
+					str_read tmp;
+					tmp.chr_id = tmp_aln->getRefID();	//check string in binary???
 					tmp.start = tmp_aln->getPosition();
 					tmp.length = tmp_aln->getRefLength();
-					tmp.SV_support = false;
 					fwrite(&tmp, sizeof(struct str_read), 1, ref_allel_reads);
 				}
 
 				//store the potential SVs:
 				if (!aln_event.empty()) {
-					add_events(tmp_aln, aln_event, 0, ref_space, bst, root, num_reads);
+					add_events(tmp_aln, aln_event, 0, ref_space, bst, root, num_reads, false);
 				}
 				if (!split_events.empty()) {
-					add_splits(tmp_aln, split_events, 1, ref, bst, root, num_reads);
+					add_splits(tmp_aln, split_events, 1, ref, bst, root, num_reads, false);
 				}
 			}
 		}
@@ -297,45 +299,40 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 
 		if (num_reads % 10000 == 0) {
 			cout << "\t\t# Processed reads: " << num_reads << endl;
-			//" \r";
-			//std::cout.flush();
 		}
 	}
 //filter and copy results:
 	std::cout << "Finalizing  .." << std::endl;
 	std::vector<Breakpoint *> points;
 	bst.get_breakpoints(root, points);
-	//std::cout<<"got breakpoints"<<std::endl;
 
-	//polish_points(points, ref);
+	/*	if (Parameter::Instance()->genotype) {
+		fclose(ref_allel_reads);
+		go->update_SVs(points, ref_space);
+		string del = "rm ";
+		del += Parameter::Instance()->tmp_genotyp;
+		del += "ref_allele";
+		system(del.c_str());
+	}*/
+
 	for (int i = 0; i < points.size(); i++) {
-		//std::cout<<"start check"<<" "<<i<<std::endl;
-		if (should_be_stored(points[i])) {
+		points[i]->calc_support();
+		if (points[i]->get_valid()) {
+			//invoke update over ref support!
 			if (points[i]->get_SVtype() & TRA) {
-
 				final.insert(points[i], root_final);
-				//		std::cout<<"Done insert"<<" "<<i<<std::endl;
 			} else {
-				//		std::cout<<"start print"<<" "<<i<<std::endl;
 				printer->printSV(points[i]);
-				//		std::cout<<"Done print"<<" "<<i<<std::endl;
 			}
 		}
 	}
-	//std::cout<<"Fine"<<std::endl;
 	bst.clear(root);
-	if (Parameter::Instance()->genotype) {
-		fclose(ref_allel_reads);
-	}
-//	sweep->finalyze();
-
 	points.clear();
 	final.get_breakpoints(root_final, points);
 	//std::cout<<"Detect merged tra"<<std::endl;
 	size_t points_size = points.size();
 	for (size_t i = 0; i < points_size; i++) { // its not nice, but I may alter the length of the vector within the loop.
 		if (points[i]->get_SVtype() & TRA) {
-
 			vector<Breakpoint *> new_points;
 			detect_merged_svs(points[i]->get_coordinates(), ref, new_points);
 			if (!new_points.empty()) {							// I only allow for 1 split!!
@@ -357,7 +354,7 @@ void detect_breakpoints(std::string read_filename, IPrinter *& printer) {
 	//std::cout<<"Done"<<std::endl;
 }
 
-void add_events(Alignment *& tmp, std::vector<str_event> events, short type, long ref_space, IntervallContainer & bst, TNode *&root, long read_id) {
+void add_events(Alignment *& tmp, std::vector<str_event> events, short type, long ref_space, IntervallTree & bst, TNode *&root, long read_id, bool add) {
 
 	bool flag = (strcmp(tmp->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
 	for (size_t i = 0; i < events.size(); i++) {
@@ -369,6 +366,7 @@ void add_events(Alignment *& tmp, std::vector<str_event> events, short type, lon
 			read.type = 0;
 		}
 		read.SV = events[i].type;
+		read.sequence = events[i].sequence;
 
 		if (flag) {
 			std::cout << "ADD EVENT " << tmp->getName() << " " << tmp->getRefID() << " " << events[i].pos << " " << abs(events[i].length) << std::endl;
@@ -420,23 +418,22 @@ void add_events(Alignment *& tmp, std::vector<str_event> events, short type, lon
 			read.coordinates.first = svs.start.min_pos;
 			read.coordinates.second = svs.stop.max_pos;
 		}
-		/*if(read.SV & DEL){
-		 std::cout<<"ADD DEL: "<<svs.start.min_pos<< " "<<svs.stop.max_pos<<" "<<tmp->getName()<<std::endl;
-		 }*/
-		/*if(read.SV & INS){
-		 std::cout<<"ALN LEN: "<<events[i].length<<" Pos: "<<svs.start.min_pos<< " "<<svs.stop.max_pos<<" "<<tmp->getName()<<std::endl;
-		 }*/
+
 		read.id = read_id;
 		svs.support[tmp->getName()] = read;
 		svs.support[tmp->getName()].length = events[i].length;
 		Breakpoint * point = new Breakpoint(svs, events[i].length);
-		bst.insert(point, root);
+		if (add) {
+			bst.insert_existant(point, root);
+		} else {
+			bst.insert(point, root);
+		}
 		//std::cout<<"Print:"<<std::endl;
 		//bst.print(root);
 	}
 }
 
-void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVector ref, IntervallContainer & bst, TNode *&root, long read_id) {
+void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVector ref, IntervallTree& bst, TNode *&root, long read_id, bool add) {
 	bool flag = (strcmp(tmp->getName().c_str(), Parameter::Instance()->read_name.c_str()) == 0);
 
 	if (flag) {
@@ -455,6 +452,7 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 		position_str svs;
 		//position_str stop;
 		read_str read;
+		read.sequence = "NA";
 		//read.name = tmp->getName();
 		read.type = type;
 		read.SV = 0;
@@ -488,20 +486,34 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 				}
 
 				if ((svs.stop.max_pos - svs.start.min_pos) > Parameter::Instance()->min_length * -1 && ((svs.stop.max_pos - svs.start.min_pos) + (Parameter::Instance()->min_length) < (svs.read_stop - svs.read_start) && (svs.read_stop - svs.read_start) > (Parameter::Instance()->min_length * 2))) {
-					if (flag) {
-						cout << "INS: " << endl;
-					}
-
-					if (!events[i].cross_N || (double)((svs.stop.max_pos - svs.start.min_pos) + Parameter::Instance()->min_length) < ((double)(svs.read_stop - svs.read_start) * Parameter::Instance()->avg_ins)) {
+					if (!events[i].cross_N || (double) ((svs.stop.max_pos - svs.start.min_pos) + Parameter::Instance()->min_length) < ((double) (svs.read_stop - svs.read_start) * Parameter::Instance()->avg_ins)) {
 						svs.stop.max_pos += (svs.read_stop - svs.read_start); //TODO check!
+						if (Parameter::Instance()->print_seq) {
+							svs.read_stop = events[i].read_pos_start;
+							svs.read_start = events[i - 1].read_pos_stop;
+							if (svs.read_stop > tmp->getAlignment()->QueryBases.size()) {
+								cerr << "BUG: split read ins! " << svs.read_stop << " " << tmp->getAlignment()->QueryBases.size() << " " << tmp->getName() << endl;
+							}
+							if (!events[i - 1].strand) {
+								std::string tmp_seq = reverse_complement(tmp->getAlignment()->QueryBases);
+
+								read.sequence = reverse_complement(tmp_seq.substr(svs.read_start, svs.read_stop - svs.read_start));
+							} else {
+								read.sequence = tmp->getAlignment()->QueryBases.substr(svs.read_start, svs.read_stop - svs.read_start);
+							}
+							if (flag) {
+								cout << "INS: " << endl;
+								cout << "split read ins! " << events[i - 1].read_pos_stop << " " << events[i].read_pos_start << " " << " " << tmp->getAlignment()->QueryBases.size() << " " << tmp->getName() << endl;
+								cout << "Seq+:" << read.sequence << endl;
+							}
+						}
 						read.SV |= INS;
 					} else {
 						read.SV |= 'n';
 					}
 
 				} else if ((svs.start.min_pos - svs.stop.max_pos) * -1 > (svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length)) {
-					//cout << "DEL1 "<<(double)(svs.start.min_pos - svs.stop.max_pos) * Parameter::Instance()->avg_del * -1.0  <<" "<<((svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length)) << endl;
-					if (!events[i].cross_N || (double)(svs.start.min_pos - svs.stop.max_pos) * Parameter::Instance()->avg_del * -1.0 > (double)((svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length))) {
+					if (!events[i].cross_N || (double) (svs.start.min_pos - svs.stop.max_pos) * Parameter::Instance()->avg_del * -1.0 > (double) ((svs.read_stop - svs.read_start) + (Parameter::Instance()->min_length))) {
 						read.SV |= DEL;
 						if (flag) {
 							cout << "DEL2" << endl;
@@ -546,10 +558,6 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 						svs.start.min_pos = svs.stop.max_pos;
 						svs.stop.max_pos = tmp;
 					}
-					//	if(flag){
-					//		std::cout<<"NEST: "<<svs.start.min_pos- get_ref_lengths(events[i - 1].RefID, ref) << " "<<svs.stop.max_pos - get_ref_lengths(events[i - 1].RefID, ref)<<" "<<tmp->getName()<<std::endl;
-					//	}
-					//	svs.stop.max_pos = svs.start.min_pos + Parameter::Instance()->min_length * 2;
 				} else if (!is_overlapping) {
 					read.SV |= INV;
 					if (events[i - 1].strand) {
@@ -627,34 +635,18 @@ void add_splits(Alignment *& tmp, std::vector<aln_str> events, short type, RefVe
 				read.coordinates.first = svs.start.min_pos;
 				read.coordinates.second = svs.stop.max_pos;
 			}
-			/*	if (read.SV & TRA) {
-			 std::cout << "SPLIT: " << TRANS_type(read.SV)<<" "<<svs.start.min_pos - get_ref_lengths(events[i].RefID, ref)<<" ";
-			 if (events[i - 1].strand) {
-			 std::cout << " +";
-			 } else {
-			 std::cout << " -";
-			 }
-			 if (events[i].strand) {
-			 std::cout << " +";
-			 } else {
-			 std::cout << " -";
-			 }
-			 std::cout <<std::endl;
-			 }*/
-			/*if(read.SV & INS){
-			 std::cout<<"Split LEN: "<<abs(read.coordinates.second-read.coordinates.first)<<" Pos: "<<read.coordinates.first-get_ref_lengths(events[i - 1].RefID, ref)<<tmp->getName()<<std::endl;
-			 }*/
-			//if( abs(read.coordinates.second-read.coordinates.first)<10){
-			///	events[i].length=abs(read.coordinates.second-read.coordinates.first);//TODO try
-			//	std::cout<<"Split event ===1 "<<" "<<abs(read.coordinates.second-read.coordinates.first)<<" len: "<< events[i].length<<" Pos "<<events[i].pos <<" Name "<<tmp->getName() <<std::endl;
-			//	}
+
 			//pool out?
 			read.id = read_id;
 			svs.support[tmp->getName()] = read;
 			svs.support[tmp->getName()].length = abs(read.coordinates.second - read.coordinates.first);
 			Breakpoint * point = new Breakpoint(svs, abs(read.coordinates.second - read.coordinates.first));
 			//std::cout<<"split ADD: " << <<" Name: "<<tmp->getName()<<" "<< svs.start.min_pos- get_ref_lengths(events[i].RefID, ref)<<"-"<<svs.stop.max_pos- get_ref_lengths(events[i].RefID, ref)<<std::endl;
-			bst.insert(point, root);
+			if (add) {
+				bst.insert_existant(point, root);
+			} else {
+				bst.insert(point, root);
+			}
 			//	std::cout<<"Print:"<<std::endl;
 			//	bst.print(root);
 		}
