@@ -15,6 +15,7 @@
 struct breakpoint_node {
 	std::string chr;
 	int position; // value to store!
+	bool direction;
 	int ref_support;
 	breakpoint_node *left;
 	breakpoint_node *right;
@@ -29,7 +30,7 @@ public:
 	~Breakpoint_Tree(){
 	}
 	void find(int position,std::string chr, breakpoint_node *par, breakpoint_node *&loc);
-	void insert(breakpoint_node *&tree, std::string chr,int position);
+	void insert(breakpoint_node *&tree, std::string chr,int position,bool direction);
 	void del(int position,std::string chr);
 	void case_a(breakpoint_node *par, breakpoint_node *loc);
 	void case_b(breakpoint_node *par, breakpoint_node *loc);
@@ -39,7 +40,7 @@ public:
 	void postorder(breakpoint_node *ptr);
 	void display(breakpoint_node *ptr, int);
 	void get_nodes(breakpoint_node *ptr, std::vector<int> & nodes);
-	void overalps(int start,int stop,std::string chr, breakpoint_node *par, bool SV_support);
+	void overalps(int start,int stop,std::string chr, breakpoint_node *par);
 	int get_ref(breakpoint_node *&tree, std::string chr, int position);
 };
 
